# Generated by Django 3.0.5 on 2020-06-07 10:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('db', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='visibility',
            field=models.BooleanField(default=False, help_text='Give the visibility status of the post', verbose_name='visibility'),
        ),
        migrations.AlterField(
            model_name='post',
            name='title',
            field=models.CharField(help_text='Title of post', max_length=255, verbose_name='title'),
        ),
    ]
